@@ -353,7 +353,7 @@ def test_histogram_buckets_as_distributions(aggregator, dd_run_check, mock_http_
         0.002,
         0.004,
         True,
-        check.hostname,
+        '',
         ['endpoint:test', 'url:http://127.0.0.1:8080/api', 'verb:GET', 'upper_bound:0.004', 'lower_bound:0.002'],
     )
     aggregator.assert_histogram_bucket(
@@ -362,7 +362,7 @@ def test_histogram_buckets_as_distributions(aggregator, dd_run_check, mock_http_
         0,
         0.001,
         True,
-        check.hostname,
+        '',
         ['endpoint:test', 'url:http://127.0.0.1:8080/api', 'verb:GET', 'upper_bound:0.001', 'lower_bound:0'],
     )
     aggregator.assert_histogram_bucket(
@@ -371,7 +371,7 @@ def test_histogram_buckets_as_distributions(aggregator, dd_run_check, mock_http_
         0.001,
         0.002,
         True,
-        check.hostname,
+        '',
         ['endpoint:test', 'url:http://127.0.0.1:8080/api', 'verb:GET', 'upper_bound:0.002', 'lower_bound:0.001'],
     )
     aggregator.assert_histogram_bucket(
@@ -380,7 +380,7 @@ def test_histogram_buckets_as_distributions(aggregator, dd_run_check, mock_http_
         0.004,
         0.008,
         True,
-        check.hostname,
+        '',
         ['endpoint:test', 'url:http://127.0.0.1:8080/api', 'verb:GET', 'upper_bound:0.008', 'lower_bound:0.004'],
     )
     aggregator.assert_histogram_bucket(
@@ -389,7 +389,7 @@ def test_histogram_buckets_as_distributions(aggregator, dd_run_check, mock_http_
         0.008,
         0.016,
         True,
-        check.hostname,
+        '',
         ['endpoint:test', 'url:http://127.0.0.1:8080/api', 'verb:GET', 'upper_bound:0.016', 'lower_bound:0.008'],
     )
     aggregator.assert_histogram_bucket(
@@ -398,7 +398,7 @@ def test_histogram_buckets_as_distributions(aggregator, dd_run_check, mock_http_
         0.016,
         0.032,
         True,
-        check.hostname,
+        '',
         ['endpoint:test', 'url:http://127.0.0.1:8080/api', 'verb:GET', 'upper_bound:0.032', 'lower_bound:0.016'],
     )
     aggregator.assert_histogram_bucket(
@@ -407,7 +407,7 @@ def test_histogram_buckets_as_distributions(aggregator, dd_run_check, mock_http_
         0.032,
         0.064,
         True,
-        check.hostname,
+        '',
         ['endpoint:test', 'url:http://127.0.0.1:8080/api', 'verb:GET', 'upper_bound:0.064', 'lower_bound:0.032'],
     )
     aggregator.assert_histogram_bucket(
@@ -416,7 +416,7 @@ def test_histogram_buckets_as_distributions(aggregator, dd_run_check, mock_http_
         0.064,
         0.128,
         True,
-        check.hostname,
+        '',
         ['endpoint:test', 'url:http://127.0.0.1:8080/api', 'verb:GET', 'upper_bound:0.128', 'lower_bound:0.064'],
     )
     aggregator.assert_histogram_bucket(
@@ -425,7 +425,7 @@ def test_histogram_buckets_as_distributions(aggregator, dd_run_check, mock_http_
         0.128,
         0.256,
         True,
-        check.hostname,
+        '',
         ['endpoint:test', 'url:http://127.0.0.1:8080/api', 'verb:GET', 'upper_bound:0.256', 'lower_bound:0.128'],
     )
     aggregator.assert_histogram_bucket(
@@ -434,7 +434,7 @@ def test_histogram_buckets_as_distributions(aggregator, dd_run_check, mock_http_
         0.256,
         0.512,
         True,
-        check.hostname,
+        '',
         ['endpoint:test', 'url:http://127.0.0.1:8080/api', 'verb:GET', 'upper_bound:0.512', 'lower_bound:0.256'],
     )
     aggregator.assert_histogram_bucket(
@@ -443,7 +443,7 @@ def test_histogram_buckets_as_distributions(aggregator, dd_run_check, mock_http_
         0.512,
         float('Inf'),
         True,
-        check.hostname,
+        '',
         ['endpoint:test', 'url:http://127.0.0.1:8080/api', 'verb:GET', 'upper_bound:inf', 'lower_bound:0.512'],
     )
 
@@ -499,7 +499,7 @@ def test_histogram_buckets_as_distributions_with_counters(aggregator, dd_run_che
         0.002,
         0.004,
         True,
-        check.hostname,
+        '',
         ['endpoint:test', 'url:http://127.0.0.1:8080/api', 'verb:GET', 'upper_bound:0.004', 'lower_bound:0.002'],
     )
     aggregator.assert_histogram_bucket(
@@ -508,7 +508,7 @@ def test_histogram_buckets_as_distributions_with_counters(aggregator, dd_run_che
         0,
         0.001,
         True,
-        check.hostname,
+        '',
         ['endpoint:test', 'url:http://127.0.0.1:8080/api', 'verb:GET', 'upper_bound:0.001', 'lower_bound:0'],
     )
     aggregator.assert_histogram_bucket(
@@ -517,7 +517,7 @@ def test_histogram_buckets_as_distributions_with_counters(aggregator, dd_run_che
         0.001,
         0.002,
         True,
-        check.hostname,
+        '',
         ['endpoint:test', 'url:http://127.0.0.1:8080/api', 'verb:GET', 'upper_bound:0.002', 'lower_bound:0.001'],
     )
     aggregator.assert_histogram_bucket(
@@ -526,7 +526,7 @@ def test_histogram_buckets_as_distributions_with_counters(aggregator, dd_run_che
         0.004,
         0.008,
         True,
-        check.hostname,
+        '',
         ['endpoint:test', 'url:http://127.0.0.1:8080/api', 'verb:GET', 'upper_bound:0.008', 'lower_bound:0.004'],
     )
     aggregator.assert_histogram_bucket(
@@ -535,7 +535,7 @@ def test_histogram_buckets_as_distributions_with_counters(aggregator, dd_run_che
         0.008,
         0.016,
         True,
-        check.hostname,
+        '',
         ['endpoint:test', 'url:http://127.0.0.1:8080/api', 'verb:GET', 'upper_bound:0.016', 'lower_bound:0.008'],
     )
     aggregator.assert_histogram_bucket(
@@ -544,7 +544,7 @@ def test_histogram_buckets_as_distributions_with_counters(aggregator, dd_run_che
         0.016,
         0.032,
         True,
-        check.hostname,
+        '',
         ['endpoint:test', 'url:http://127.0.0.1:8080/api', 'verb:GET', 'upper_bound:0.032', 'lower_bound:0.016'],
     )
     aggregator.assert_histogram_bucket(
@@ -553,7 +553,7 @@ def test_histogram_buckets_as_distributions_with_counters(aggregator, dd_run_che
         0.032,
         0.064,
         True,
-        check.hostname,
+        '',
         ['endpoint:test', 'url:http://127.0.0.1:8080/api', 'verb:GET', 'upper_bound:0.064', 'lower_bound:0.032'],
     )
     aggregator.assert_histogram_bucket(
@@ -562,7 +562,7 @@ def test_histogram_buckets_as_distributions_with_counters(aggregator, dd_run_che
         0.064,
         0.128,
         True,
-        check.hostname,
+        '',
         ['endpoint:test', 'url:http://127.0.0.1:8080/api', 'verb:GET', 'upper_bound:0.128', 'lower_bound:0.064'],
     )
     aggregator.assert_histogram_bucket(
@@ -571,7 +571,7 @@ def test_histogram_buckets_as_distributions_with_counters(aggregator, dd_run_che
         0.128,
         0.256,
         True,
-        check.hostname,
+        '',
         ['endpoint:test', 'url:http://127.0.0.1:8080/api', 'verb:GET', 'upper_bound:0.256', 'lower_bound:0.128'],
     )
     aggregator.assert_histogram_bucket(
@@ -580,7 +580,7 @@ def test_histogram_buckets_as_distributions_with_counters(aggregator, dd_run_che
         0.256,
         0.512,
         True,
-        check.hostname,
+        '',
         ['endpoint:test', 'url:http://127.0.0.1:8080/api', 'verb:GET', 'upper_bound:0.512', 'lower_bound:0.256'],
     )
     aggregator.assert_histogram_bucket(
@@ -589,7 +589,7 @@ def test_histogram_buckets_as_distributions_with_counters(aggregator, dd_run_che
         0.512,
         float('Inf'),
         True,
-        check.hostname,
+        '',
         ['endpoint:test', 'url:http://127.0.0.1:8080/api', 'verb:GET', 'upper_bound:inf', 'lower_bound:0.512'],
     )
 
